@@ -4,20 +4,20 @@
 
    http://www.tango-controls.org/static/PyTango/latest/doc/html/index.html
 
-   (copyleft) CELLS / ALBA Synchrotron, Bellaterra, Spain
-  
-   This is free software; you can redistribute it and/or modify
+   Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+   
+   PyTango is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-  
-   This software is distributed in the hope that it will be useful,
+   
+   PyTango is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.
   
    You should have received a copy of the GNU Lesser General Public License
-   along with this program; if not, see <http://www.gnu.org/licenses/>.
+   along with PyTango.  If not, see <http://www.gnu.org/licenses/>.
    
 *******************************************************************************/
 
@@ -381,7 +381,7 @@ namespace PyEncodedAttribute
         unsigned char *buffer;
         int width, height;
 
-        self.decode_gray8(attr, &width, &height, &buffer, true);
+        self.decode_gray8(attr, &width, &height, &buffer);
         
         char *ch_ptr = reinterpret_cast<char *>(buffer);
         PyObject *ret = NULL;
